<?php
// $Id$

/**
 * @file
 * Themes hooks and callback functions
 * 
 * @TODO - comment all functions
 */
 
function theme_user_notifications_unread_count_link($link_text = '', $hide_empty = FALSE, $raw = FALSE) {
	$count = user_notifications_unread_count();
	if (empty($count) && $hide_empty) {
		return;
	}
	
	$inbox = $link_text ? $link_text : t('Notifications');
	if ($count > 0) {
		$inbox .= ' (<strong>'. format_plural($count, '1 new', '@count new') .'</strong>)';
	}
	
	//output as raw text no link
	if ($raw) {
		return $inbox;
	}
	return l($inbox, 'user-notifications', array('html' => true, 'attributes' => array('title' => t("Notifications and messages from other users"))));
}

/**
 * themes date headers on notifications page
 */
function theme_user_notifications_date_header($date, $format = 'D jS M Y') {
	return '<h3 class="notification-date-header">'. format_date($date, 'custom', $format) .'</h3>';
}

/**
 * Render $message array
 * @TODO - Add first/last classes to notifications
 */
function template_preprocess_user_notifications_row(&$vars) {
	$notification = $vars['notification'];
  
	$vars['classes_array'] = array();
	if ($notification->is_new) {
		$vars['classes_array'][] = 'notification-is-new';
	}
	if ($notification->tag) {
		$vars['classes_array'][] = 'notification-'. str_replace('_', '-', trim(strtolower(check_plain($notification->tag))));
	}	
	
	$vars['classes'] = !empty($vars['classes_array']) ? ' '. implode(' ', $vars['classes_array']) : '';
	$vars['message']['time'] = format_date($notification->timestamp, 'custom', 'g:ia');
	$vars['message']['time_ago'] = t('@time ago', array('@time' => format_interval(time() - $notification->timestamp)));
	$vars['message']['subject'] = check_plain($notification->subject);
	$vars['message']['body'] = check_markup($notification->body, $notification->format);
	
	// template suggestions depending on $vars['display']
	// NOTE: requires copy of user-notifications-row.tpl.php your theme to allow other tpls below
	$vars['template_files'][] = 'user-notifications-row-'. $vars['display'];
	$vars['template_files'][] = 'user-notifications-row-'. $vars['display'] .'-'. $notification->tag;
	$vars['template_files'][] = 'user-notifications-row-'. $notification->tag;
}

/**
 * themes a notification when displayed in a feed
 */
function template_preprocess_user_notifications_row_feed(&$vars) {
	$notification = $vars['notification'];
	$vars['feed']['title'] = check_plain($notification->subject);
	$vars['feed']['link'] = check_url(url("user-notifications", array('absolute' => TRUE)));
	$vars['feed']['description'] = check_plain(strip_tags($notification->body));
	$vars['feed']['args'] = format_xml_elements($notification->feed_args);
}
 

/**
 * stub theme function to allow overrides
 * 
 * @param $account
 *  User account object the notifications related to
 * @param $rows
 *   An array of the notifications (array gives more display options)
 * @param $page
 *  If TRUE its a page display, FALSE is a block display
 * 
 * @see - user_notifications.pages.inc
 */
function theme_user_notifications_notification_list($account, $rows = array(), $page = TRUE) {
	global $user;
	if (!empty($rows)) {
	  $output = implode('', $rows);
	  if ($page) {
		  $output .= theme('pager');
		}
	}
	else {
		$output = '<div class="no-notifications">'. t('No notifications to show.') .'</div>';
	}
	
	if ($user->uid == $account->uid && user_access('administer own notifications')) {
	  //relates to allowing users to admin own settings
		$output .= l(t('Notification Settings'), 'user/'. $account->uid .'/edit/user_notifications');
	}
	
	if (!$page) {
		$output .= theme('more_link', url('user-notifications'), t('All Notification'));
	}
	return $output;
}

/**
 * outputs notifications list in block
 * 
 * @param $account
 *  User account object the notifications related to
 * 
 * @see - user_notifications.pages.inc
 */
function theme_user_notifications_notification_list_block($account = '', $limit = '5', $markasread = FALSE, $grouped = FALSE) {
  global $user;
  if (empty($account)) {
	  $account = $user;
	}
	
	$result = user_notifications_display_query($account, FALSE, FALSE, $limit);
	$headers = array();
	while ($notification = db_fetch_object($result)) {
		$row = '';
		if ($grouped) {
			$header = theme('user_notifications_date_header', $notification->timestamp);
			if (empty($headers[$header])) {
				$row = $header;
				$headers[$header] = $header;
			}
		}
		$row .= theme('user_notifications_row', $notification, 'block');
		$rows[] = $row;
		$notifications[$notification->nid] = $notification;
	}
	
	if ($markasread) {
    //markup these notifications as read after rendering
	  user_notifications_markasread($notifications);	
	}

	return theme('user_notifications_notification_list', $account, $rows, FALSE);
}

/**
 * theme the user notifiations settings form
 */
function theme_user_notifications_user_settings_form($form) {
  $header = array(t('Event'), t('Settings'));
  foreach (element_children($form['user_notifications']) as $key) {
    $row = array();
    $row[] = drupal_render($form['user_notifications'][$key]['title']);
    $row[] = !empty($form['user_notifications'][$key]['disabled_send_methods']) ? drupal_render($form['user_notifications'][$key]['disabled_send_methods']) : t('No additional notifications methods allowed');
    $rows[] = $row;
  }
	
	$output .= drupal_render($form['user_notifications_help']);
  $output .= theme('table', $header, $rows);
	
  // Now we render whatever is left of the table, for instance the submit buttons
  $output .= drupal_render($form);
  return $output;
}